Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2483)

Unified Diff: chrome/browser/supervised_user/supervised_user_service.cc

Issue 2551023006: [Sync] SyncEngine 1.5: Fix all backend references in PSS. (Closed)
Patch Set: Fix Android. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/supervised_user/supervised_user_service.cc
diff --git a/chrome/browser/supervised_user/supervised_user_service.cc b/chrome/browser/supervised_user/supervised_user_service.cc
index 1f257853e9f11c9f7d0942abce31e321cb4a4ac1..aed7f3d89a55ad335743481e7876bb978668c795 100644
--- a/chrome/browser/supervised_user/supervised_user_service.cc
+++ b/chrome/browser/supervised_user/supervised_user_service.cc
@@ -723,14 +723,14 @@ void SupervisedUserService::StartSetupSync() {
}
void SupervisedUserService::FinishSetupSyncWhenReady() {
// If we're already waiting for the Sync backend, there's nothing to do here.
if (waiting_for_sync_initialization_)
return;
// Continue in FinishSetupSync() once the Sync backend has been initialized.
browser_sync::ProfileSyncService* service =
ProfileSyncServiceFactory::GetForProfile(profile_);
- if (service->IsBackendInitialized()) {
+ if (service->IsEngineInitialized()) {
FinishSetupSync();
} else {
service->AddObserver(this);
@@ -741,7 +741,7 @@ void SupervisedUserService::FinishSetupSyncWhenReady() {
void SupervisedUserService::FinishSetupSync() {
browser_sync::ProfileSyncService* service =
ProfileSyncServiceFactory::GetForProfile(profile_);
- DCHECK(service->IsBackendInitialized());
+ DCHECK(service->IsEngineInitialized());
// Sync nothing (except types which are set via GetPreferredDataTypes).
bool sync_everything = false;
@@ -1263,7 +1263,7 @@ syncer::ModelTypeSet SupervisedUserService::GetPreferredDataTypes() const {
void SupervisedUserService::OnStateChanged() {
browser_sync::ProfileSyncService* service =
ProfileSyncServiceFactory::GetForProfile(profile_);
- if (waiting_for_sync_initialization_ && service->IsBackendInitialized()) {
+ if (waiting_for_sync_initialization_ && service->IsEngineInitialized()) {
waiting_for_sync_initialization_ = false;
service->RemoveObserver(this);
FinishSetupSync();
@@ -723,14 +723,14 @@ void SupervisedUserService::StartSetupSync() {
}
void SupervisedUserService::FinishSetupSyncWhenReady() {
- // If we're already waiting for the Sync backend, there's nothing to do here.
+ // If we're already waiting for the sync engine, there's nothing to do here.
if (waiting_for_sync_initialization_)
return;
@@ -723,14 +723,14 @@ void SupervisedUserService::StartSetupSync() {
if (waiting_for_sync_initialization_)
return;
- // Continue in FinishSetupSync() once the Sync backend has been initialized.
+ // Continue in FinishSetupSync() once the sync engine has been initialized.
browser_sync::ProfileSyncService* service =
ProfileSyncServiceFactory::GetForProfile(profile_);

Powered by Google App Engine
This is Rietveld 408576698